<?php

namespace FiloBlu\ExtMailChimp\Block\Adminhtml\System\Config\Form\Field;

use Ebizmarts\MailChimp\Block\Adminhtml\System\Config\Form\Field\MailchimpMap;
use Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray;
use Magento\Framework\DataObject;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\View\Element\BlockInterface;

/**
 * Class SubscriberMap
 * @package FiloBlu\ExtMailChimp\Block\Adminhtml\System\Config\Form\Field
 */
class SubscriberMap extends AbstractFieldArray
{
    /**
     * @var VarsMap
     */
    protected $_varsRenderer=null;
    /**
     * @var MailchimpMap
     */
    protected $_mailchimpRenderer=null;

    /**
     * @return VarsMap|BlockInterface
     * @throws LocalizedException
     */
    protected function _getVarsRenderer()
    {
        if (!$this->_varsRenderer) {
            $this->_varsRenderer = $this->getLayout()->createBlock(
                VarsMap::class,
                '',
                ['data' => ['is_render_to_js_template' => true]]
            );
            $this->_varsRenderer->setClass('customer_field_select');
        }
        return $this->_varsRenderer;
    }

    /**
     * @return BlockInterface|null
     * @throws LocalizedException
     */
    protected function _getMailchimpRenderer()
    {
        if (!$this->_mailchimpRenderer) {
            $this->_mailchimpRenderer = $this->getLayout()->createBlock(
                MailchimpMap::class,
                '',
                ['data' => ['is_render_to_js_template' => true]]
            );
            $this->_mailchimpRenderer->setClass('mailchimp_field_select');
        }
        return $this->_mailchimpRenderer;
    }

    /**
     *
     */
    protected function _prepareToRender()
    {
        $this->addColumn(
            'mailchimp_field_id',
            ['label' => __('Mailchimp'), 'renderer' => $this->_getMailchimpRenderer()]
        );
        $this->addColumn(
            'customer_field_id',
            ['label' => __('Magento'), 'renderer' => $this->_getVarsRenderer()]
        );
        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add');
    }

    /**
     * @param DataObject $row
     * @throws LocalizedException
     */
    protected function _prepareArrayRow(DataObject $row)
    {
        $optionExtraAttr = [];
        $optionExtraAttr['option_' . $this->_getVarsRenderer()->calcOptionHash($row->getData('customer_field_id'))] =
            'selected="selected"';
        $optionExtraAttr['option_' . $this->_getMailchimpRenderer()->calcOptionHash(
            $row->getData('mailchimp_field_id')
        )
        ] =
            'selected="selected"';
        $row->setData(
            'option_extra_attrs',
            $optionExtraAttr
        );
    }
}
